#define M_PI 3.1415926535897932384626433832795

varying vec3 e;
varying vec3 n;

uniform float elapsedTime;

uniform float temperature;

uniform sampler2D coronaTexture;
uniform sampler2D temperatureTexture;

uniform float coronaFalloff;
uniform float coronaRadius;
uniform float coronaAlpha;
uniform float coronaEdgeBlend;
uniform float coronaTexCurve;

uniform float cmeRadius;
uniform float cmeGlowPower;

uniform float moveSpeed;
uniform float stretch;

varying vec3 vPosition;
varying vec3 vNormal;
varying vec2 vUv;


float lerp(float edge0, float edge1, float value) {
    return (clamp(value, edge0, edge1) - edge0) / (edge1 - edge0);
}

vec4 get(float uSpeed, float vSpeed) {
	float x = vUv.x + elapsedTime * vSpeed;
	return texture2D(coronaTexture, vec2(vUv.y+elapsedTime*uSpeed, x));
}


void main() {
	float power = pow(abs(dot(-e, n)), coronaFalloff);
	power = mix(power, 0.0, abs(vUv.y*2.0 - 1.0));

	float SPEEEEEED = 0.5;
	vec4 a = get( 0.14 * SPEEEEEED, -0.1  );
	vec4 b = get(-0.2  * SPEEEEEED, -0.04 );
	gl_FragColor = (a*0.5) + (b*0.5);
	gl_FragColor.a = power;
	
	float intensity = length(gl_FragColor);
	intensity = pow(intensity, 2.5) * coronaAlpha;

	gl_FragColor.rgb = texture2D(temperatureTexture, vec2(intensity, temperature)).rgb;

	float dist = length(vPosition);
	float innerFade = smoothstep(1.0, coronaEdgeBlend, dist);

	gl_FragColor.a = min(intensity, innerFade);
}